/*
 * This file is part of Composer.
 *
 * Composer is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Composer is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Composer; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA 
 */

package org.gnu.composer.CommonTools;

public class Nap
{

	/**
	 * Wraps the thread sleep call including the 
	 * try/catch block
	 * @param timeInMillisecs
	 */
	public static void rest(long timeInMillisecs)
	{
		try 
		{
			Thread.sleep(timeInMillisecs);
		}
		catch (InterruptedException e)
		{
			// Waking up from the Nap early is okay
			// just don't want to cause an error by
			// letting it slip past.
		}
	}
	
	/**
	 * Sleeps for a period of time in a synchronized
	 * wait waiting for a notification on a given object.
	 * @param timeInMillisecs
	 */
	public static void waitRest(long timeInMillisecs, Object objectToWaitFor)
	{
		try
		{
			synchronized(objectToWaitFor)
			{
				objectToWaitFor.wait(timeInMillisecs);
			}
		}
		catch(InterruptedException e)
		{
			// Waking up from the Nap early is okay
			// just don't want to cause an error by
			// letting it slip past.
		}
	}
	
	/**
	 * Sleeps for an undefinate amount of time waiting
	 * for a notification on a given object.
	 * @param timeInMillisecs
	 */
	public static void wait(Object objectToWaitFor)
	{
		boolean waiting = true;
		while(waiting)
		{
			try
			{
				synchronized(objectToWaitFor)
				{
					objectToWaitFor.wait();
					waiting = false;
				}
			}
			catch(InterruptedException e)
			{
				//Something happened, but it was not our
				//notification.
			}
		}
		
	}
	
	/**
	 * Wakes up a given thread that is sleeping with
	 * a Thread.wait or a RaptorNap.waitRest call.
	 * @param threadToWake - thread to wake up.
	 */
	public static void notify(Object threadToWake)
	{
		synchronized(threadToWake)
		{
			threadToWake.notify();
		}
	}
}
