/*
 * This file is part of Composer.
 *
 * Composer is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Composer is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Composer; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA 
 */

package org.gnu.composer.DB;

import java.sql.Timestamp;

public class Backup 
{
	private int       backupid_;
	private String    name_;
	private boolean   isnew_;
	private int       discsize_;
	private Disc      disc_;
	private Timestamp creationdate_;
	
	/**
	 * Creates a new backup with a unique id and
	 * no associated tracks. This is the constructor
	 * to call when making a new backup.
	 */
	public Backup()
	{
		backupid_     = DBAccess.nextBackupid();
		creationdate_ = new Timestamp(System.currentTimeMillis());
		name_         = null;
		isnew_        = true;
		discsize_         = 0;
		disc_         = new Disc();
	}
	
	/**
	 * When retrieving a backup from the db, this constructor
	 * will create a blank backup for filling in. This does
	 * not create a new backup in the db.
	 * @param backupid
	 * @param timestamp
	 */
	public Backup(int backupid, Timestamp timestamp)
	{
		backupid_     = backupid;
		creationdate_ = timestamp;
		name_         = null;
		isnew_        = true;
		discsize_         = 0;
		disc_         = new Disc();
	}
	
	public int backupid()
	{
		return backupid_;
	}
	
	public Disc disc()
	{
		return disc_;
	}
	
	public void disc(Disc disc)
	{
		disc_ = disc;
	}
	
	public String name()
	{
		return name_;
	}
	
	public void name(String name)
	{
		name_ = name;
	}
	
	public boolean isnew()
	{
		return isnew_;
	}
	
	public void isnew(boolean isnew)
	{
		isnew_ = isnew;
	}
	
	public int discsize()
	{
		return discsize_;
	}
	
	public void discsize(int discsize)
	{
		discsize_ = discsize;
	}
	
	public Timestamp creationdate()
	{
		return creationdate_;
	}
	
	/**
	 * Update the db with the information from this
	 * job object.
	 */
	public boolean updateInDb()
	{
		boolean success;
		
		success = DBAccess.addOrUpdateBackup(this);
		
		return success;
	}
	
	/**
	 * Deletes a job from the database if it exists.
	 * @return true iff the job existed and was 
	 * successfully deleted. False otherwise.
	 */
	public boolean deleteFromDb()
	{
		boolean success;
		
		success = DBAccess.deleteBackup(backupid_);
		
		return success;
	}
	
	/**
	 * Retrieve a job from the db if it exists
	 * @param jobid - jobid of the job to retrieve
	 * @return the job, or null if the job dne.
	 */
	public static Backup lookupInDb(int backupid)
	{
		Backup backup = null;
		
		backup = DBAccess.lookupBackup(backupid);
		
		return backup;
	}
}
