/*
 * This file is part of Composer.
 *
 * Composer is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Composer is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Composer; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA 
 */

package org.gnu.composer.DB;

/**
 * Holder for all consts that will be used when
 * creating sql commands for inserting, updating,
 * and removing entries from the db from all
 * tables that will be used.
 * 
 * @author Branden Archer
 */
public class DBConsts 
{
	public static final String USERNAME                  = "quatre";
	public static final String PASSWORD                  = "";
	public static final String DB_URL                    = "jdbc:postgresql://localhost/composer";
	//All active jobs are stored in the following table. The table
	//shows the jobid along wcolumnIndexith the current state of the job, in
	//addition to any other configuration information.
	public static final String ACTIVE_JOB_TABLE          = "activejobs";
	public static final String ACTIVE_JOB_JOBID          = "jobid";
	public static final String ACTIVE_JOB_STATE          = "state";
	public static final String ACTIVE_JOB_LABEL          = "label";
	public static final String ACTIVE_JOB_TOTAL_DISCS    = "totaldiscs";
	public static final String ACTIVE_JOB_DONE_DISCS     = "donediscs";
	public static final String ACTIVE_JOB_ERROR_DISCS    = "errordiscs";
	
	//Individual jobs are each stored in their own table name:
	//job <jobid>
	//A job table contains each backup which is contained within the
	//job.
	public static final String INDIVIDUAL_JOB_TABLE      = "job";
	public static final String INDIVIDUAL_JOB_BACKUP     = "backupid";
	
	//There is a backup table which contains all the backups.
	//Information such as the backupid, artist, and discid are
	//listed.
	public static final String BACKUP_TABLE              = "backups";
	public static final String BACKUP_BACKUP_ID          = "backupid";
	public static final String BACKUP_NAME               = "name";
	public static final String BACKUP_NEW                = "isnew";
	public static final String BACKUP_DISC_SIZE          = "discsize";
	public static final String BACKUP_CREATION_DATE      = "creationdate";
	
	//Each disc is listed in its own table stored with the name:
	//disc <discid>
	//A disc table contains information on each track in the disc,
	//including the trackname, duration, format, et cetera.
	public static final String INDIVIDUAL_DISC_TABLE     = "disc";
	public static final String INDIVIDUAL_DISC_ARTIST    = "artist";
	public static final String INDIVIDUAL_DISC_ALBUM     = "album";
	public static final String INDIVIDUAL_DISC_TRACKNAME = "trackname";
	public static final String INDIVIDUAL_DISC_TRACKNUM  = "tracknum";
	public static final String INDIVIDUAL_DISC_DURATION  = "duration";
	public static final String INDIVIDUAL_DISC_FORMAT    = "format";
	public static final String INDIVIDUAL_DISC_BITRATE   = "bitrate";
	public static final String INDIVIDUAL_DISC_GENRE     = "genre";
	public static final String INDIVIDUAL_DISC_YEAR      = "year";
	public static final String INDIVIDUAL_DISC_SAMPLERATE= "samplerate";
	public static final String INDIVIDUAL_DISC_COMMENT   = "comment";
	
	//Configuration table settings
	public static final String CONFIG_TABLE              = "config";
	public static final String CONFIG_NAME               = "name";
	public static final String CONFIG_VALUE              = "value";
	
	//Configuration table settings
	public static final String CONFIG_NEXT_JOBID         = "nextjobid";
	public static final String CONFIG_NEXT_BACKUPID      = "nextbackupid";
}
