/*
 * This file is part of Composer.
 *
 * Composer is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Composer is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Composer; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA 
 */

package org.gnu.composer.PrinterAccess;

public class ByteMath 
{
	/**
	 * Converts a byte into the equivalent integer.
	 * This method assumes that the byte is intended
	 * to be unsigned. 
	 * @param value - value to convert
	 * @return The equilvalent value of the byte
	 * if it were unsigned.
	 */
	public static int convToUnsigned(byte value)
	{
		//If the value was negative for a byte, then nop out
		//the top '1111...' bytes that were appended.
		int intValue = value & 0xFF;
		return intValue;
	}
	
	/**
	 * Takes an integer in the range of 0-255 and
	 * converts it to a signed value, assuming the
	 * value in the "unsigned" argument represents
	 * a byte value.
	 * Ex: 0   -> 0
	 *     14  -> 14
	 *     255 -> -1
	 * @param unsigned - value to convert.
	 */
	public static int convToSigned(int unsigned)
	{
		//This code may look unnecessary, but it is
		//needed. You must explicitly convert to a 
		//byte, then back. The compiler might optimize
		//a statement like this:
		//return (int)(byte)unsigned;
		//to be the following:
		//return unsigned;
		
		byte value = (byte)unsigned;
		return (int)value;
	}
}
