/*
 * This file is part of Composer.
 *
 * Composer is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Composer is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Composer; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA 
 */

package org.gnu.composer.CommonToolsTest;

import org.gnu.composer.Tester.Tester;
import org.gnu.composer.CommonTools.*;
import org.gnu.composer.CommonTools.Command.CommandLine;
import org.gnu.composer.RuntimeSettings.*;

public class CommonToolsTest extends Tester
{
	public static void main(String [] args)
	{
		printTestInfo(
			"CommonToolsTest",
			"Tests the different common tools for proper functionality");
		
		testRunCommand();
		testStartCommand();
		
		testPassed(true);
	}
	
	/**
	 * Tests that a command which is run returns the correct return value
	 */
	public static void testRunCommand()
	{
		boolean success = true;
		
		printStepInfo(
			"testRunCommand",
			"Tests that a command which is run returns the correct return value");
		
		for(int index = 0; index < 100; index++)
		{
			try
			{
				int returned = Command.runCommand(
					RuntimeSettings.binRoot() + "RunCommandTest " + index);
				if(returned != index)
				{
					error("Expected return code " + index + " but got " + returned);
					success = false;
				}
			}
			catch(Exception e)
			{
				e.printStackTrace();
				error("Could not execute program for index " + index);
				success = false;
			}
		}
		
		stepPassed(success);
	}
	
	/**
	 * Tests that a command which is started spits out the expected string
	 */
	public static void testStartCommand()
	{
		boolean success = true;
		
		printStepInfo(
			"testStartCommand",
			"Tests that a command which is started spits out the expected string");
		
		for(int index = 0; index < 100; index++)
		{
			try
			{
				CommandLine program = Command.startCommand(
					RuntimeSettings.binRoot() + "RunCommandTest " + index);
				
				String expected = "Return Code: " + index;
				String actual = program.programStdout.readLine();
				
				if(expected.equals(actual) == false)
				{
					error("Expected \"" + expected + "\" but got \"" + actual + "\"");
					success = false;
				}
				
				int returned = Command.waitUntilCommandEnds(program);
				
				if(returned != index)
				{
					error("Expected return code " + index + " but got " + returned);
					success = false;
				}
			}
			catch(Exception e)
			{
				error("Could not execute program for index " + index);
				success = false;
			}
		}
		
		stepPassed(success);
	}
}
